Modify the set component of the memcpy test (unclear why there is a memset component to begin with).

Cette révision appartient à :
Alex Voicu
2017-11-21 17:52:01 +00:00
Parent 5e16ee0d1f
révision 4131b47134
+1 -1
Voir le fichier
@@ -23,7 +23,7 @@ __global__ void cpy(hipLaunchParm lp, uint32_t *Out, uint32_t *In)
__global__ void set(hipLaunchParm lp, uint32_t *ptr, uint8_t val, size_t size)
{
int tx = threadIdx.x;
memset(ptr + tx, val, (sizeof(uint32_t)*(size/LEN)));
memset(ptr + tx, val, sizeof(uint32_t));
}
int main()